# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: d6_TempHum.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x64\x36_TempHum.proto\"\x13\n\x11\x64\x36\x63\x31\x30\x30\x30_th_get_rq\":\n\x11\x64\x36\x63\x31\x30\x30\x30_th_get_ra\x12\x13\n\x0btemperature\x18\x01 \x01(\x11\x12\x10\n\x08humidity\x18\x02 \x01(\rb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'd6_TempHum_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _D6C1000_TH_GET_RQ._serialized_start=20
  _D6C1000_TH_GET_RQ._serialized_end=39
  _D6C1000_TH_GET_RA._serialized_start=41
  _D6C1000_TH_GET_RA._serialized_end=99
# @@protoc_insertion_point(module_scope)
