# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: d1B_Lcd.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rd1B_Lcd.proto\"\x17\n\x15\x64\x31\x62\x63\x31\x30\x30\x31_lcd_clear_rq\"\x17\n\x15\x64\x31\x62\x63\x31\x30\x30\x31_lcd_clear_ra\"/\n\x1e\x64\x31\x62\x63\x31\x30\x30\x32_lcd_back_light_set_rq\x12\r\n\x05value\x18\x01 \x01(\r\" \n\x1e\x64\x31\x62\x63\x31\x30\x30\x32_lcd_back_light_set_ra\"5\n$d1bc1003_lcd_background_color_set_rq\x12\r\n\x05\x63olor\x18\x01 \x01(\r\"&\n$d1bc1003_lcd_background_color_set_ra\";\n\x1b\x64\x31\x62\x63\x31\x30\x30\x34_lcd_bar_display_rq\x12\x0e\n\x06status\x18\x01 \x01(\r\x12\x0c\n\x04text\x18\x02 \x01(\x0c\"\x1d\n\x1b\x64\x31\x62\x63\x31\x30\x30\x34_lcd_bar_display_ra\"Z\n\x1b\x64\x31\x62\x63\x31\x30\x30\x35_lcd_static_text_rq\x12\x0c\n\x04text\x18\x01 \x01(\x0c\x12\r\n\x05\x63olor\x18\x02 \x01(\r\x12\x0e\n\x06post_x\x18\x03 \x01(\r\x12\x0e\n\x06post_y\x18\x04 \x01(\r\"\x1d\n\x1b\x64\x31\x62\x63\x31\x30\x30\x35_lcd_static_text_ra\"X\n\x19\x64\x31\x62\x63\x31\x30\x30\x36_lcd_roll_text_rq\x12\x0c\n\x04text\x18\x01 \x01(\x0c\x12\r\n\x05\x63olor\x18\x02 \x01(\r\x12\x0e\n\x06post_x\x18\x03 \x01(\r\x12\x0e\n\x06post_y\x18\x04 \x01(\r\"\x1b\n\x19\x64\x31\x62\x63\x31\x30\x30\x36_lcd_roll_text_ra\"S\n\x14\x64\x31\x62\x63\x31\x30\x30\x37_lcd_icon_rq\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\r\n\x05index\x18\x02 \x01(\r\x12\x0e\n\x06post_x\x18\x03 \x01(\r\x12\x0e\n\x06post_y\x18\x04 \x01(\r\"\x16\n\x14\x64\x31\x62\x63\x31\x30\x30\x37_lcd_icon_ra\"J\n\x19\x64\x31\x62\x63\x31\x30\x30\x38_lcd_inner_pic_rq\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0e\n\x06post_x\x18\x02 \x01(\r\x12\x0e\n\x06post_y\x18\x03 \x01(\r\"\x1b\n\x19\x64\x31\x62\x63\x31\x30\x30\x38_lcd_inner_pic_ra\"9\n\x1b\x64\x31\x62\x63\x31\x30\x30\x39_lcd_pic_display_rq\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1b\x64\x31\x62\x63\x31\x30\x30\x39_lcd_pic_display_ra\":\n\x1e\x64\x31\x62\x63\x31\x30\x31\x30_lcd_sensor_display_rq\x12\x0b\n\x03opt\x18\x01 \x01(\r\x12\x0b\n\x03\x64\x65v\x18\x02 \x01(\r\" \n\x1e\x64\x31\x62\x63\x31\x30\x31\x30_lcd_sensor_display_rab\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'd1B_Lcd_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _D1BC1001_LCD_CLEAR_RQ._serialized_start=17
  _D1BC1001_LCD_CLEAR_RQ._serialized_end=40
  _D1BC1001_LCD_CLEAR_RA._serialized_start=42
  _D1BC1001_LCD_CLEAR_RA._serialized_end=65
  _D1BC1002_LCD_BACK_LIGHT_SET_RQ._serialized_start=67
  _D1BC1002_LCD_BACK_LIGHT_SET_RQ._serialized_end=114
  _D1BC1002_LCD_BACK_LIGHT_SET_RA._serialized_start=116
  _D1BC1002_LCD_BACK_LIGHT_SET_RA._serialized_end=148
  _D1BC1003_LCD_BACKGROUND_COLOR_SET_RQ._serialized_start=150
  _D1BC1003_LCD_BACKGROUND_COLOR_SET_RQ._serialized_end=203
  _D1BC1003_LCD_BACKGROUND_COLOR_SET_RA._serialized_start=205
  _D1BC1003_LCD_BACKGROUND_COLOR_SET_RA._serialized_end=243
  _D1BC1004_LCD_BAR_DISPLAY_RQ._serialized_start=245
  _D1BC1004_LCD_BAR_DISPLAY_RQ._serialized_end=304
  _D1BC1004_LCD_BAR_DISPLAY_RA._serialized_start=306
  _D1BC1004_LCD_BAR_DISPLAY_RA._serialized_end=335
  _D1BC1005_LCD_STATIC_TEXT_RQ._serialized_start=337
  _D1BC1005_LCD_STATIC_TEXT_RQ._serialized_end=427
  _D1BC1005_LCD_STATIC_TEXT_RA._serialized_start=429
  _D1BC1005_LCD_STATIC_TEXT_RA._serialized_end=458
  _D1BC1006_LCD_ROLL_TEXT_RQ._serialized_start=460
  _D1BC1006_LCD_ROLL_TEXT_RQ._serialized_end=548
  _D1BC1006_LCD_ROLL_TEXT_RA._serialized_start=550
  _D1BC1006_LCD_ROLL_TEXT_RA._serialized_end=577
  _D1BC1007_LCD_ICON_RQ._serialized_start=579
  _D1BC1007_LCD_ICON_RQ._serialized_end=662
  _D1BC1007_LCD_ICON_RA._serialized_start=664
  _D1BC1007_LCD_ICON_RA._serialized_end=686
  _D1BC1008_LCD_INNER_PIC_RQ._serialized_start=688
  _D1BC1008_LCD_INNER_PIC_RQ._serialized_end=762
  _D1BC1008_LCD_INNER_PIC_RA._serialized_start=764
  _D1BC1008_LCD_INNER_PIC_RA._serialized_end=791
  _D1BC1009_LCD_PIC_DISPLAY_RQ._serialized_start=793
  _D1BC1009_LCD_PIC_DISPLAY_RQ._serialized_end=850
  _D1BC1009_LCD_PIC_DISPLAY_RA._serialized_start=852
  _D1BC1009_LCD_PIC_DISPLAY_RA._serialized_end=881
  _D1BC1010_LCD_SENSOR_DISPLAY_RQ._serialized_start=883
  _D1BC1010_LCD_SENSOR_DISPLAY_RQ._serialized_end=941
  _D1BC1010_LCD_SENSOR_DISPLAY_RA._serialized_start=943
  _D1BC1010_LCD_SENSOR_DISPLAY_RA._serialized_end=975
# @@protoc_insertion_point(module_scope)
