# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: d9_Ultrasonic.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x64\x39_Ultrasonic.proto\"\x18\n\x16\x64\x39\x63\x31\x30\x30\x30_ult_dis_get_rq\"*\n\x16\x64\x39\x63\x31\x30\x30\x30_ult_dis_get_ra\x12\x10\n\x08\x64istance\x18\x01 \x01(\r\"f\n\x18\x64\x39\x63\x31\x30\x30\x31_ult_light_set_rq\x12\t\n\x01R\x18\x01 \x01(\r\x12\t\n\x01G\x18\x02 \x01(\r\x12\t\n\x01\x42\x18\x03 \x01(\r\x12\x0c\n\x04mode\x18\x04 \x01(\r\x12\r\n\x05speed\x18\x05 \x01(\r\x12\x0c\n\x04time\x18\x06 \x01(\r\"\x1a\n\x18\x64\x39\x63\x31\x30\x30\x31_ult_light_set_rab\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'd9_Ultrasonic_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _D9C1000_ULT_DIS_GET_RQ._serialized_start=23
  _D9C1000_ULT_DIS_GET_RQ._serialized_end=47
  _D9C1000_ULT_DIS_GET_RA._serialized_start=49
  _D9C1000_ULT_DIS_GET_RA._serialized_end=91
  _D9C1001_ULT_LIGHT_SET_RQ._serialized_start=93
  _D9C1001_ULT_LIGHT_SET_RQ._serialized_end=195
  _D9C1001_ULT_LIGHT_SET_RA._serialized_start=197
  _D9C1001_ULT_LIGHT_SET_RA._serialized_end=223
# @@protoc_insertion_point(module_scope)
