# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dE_VoiceRecognition.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x64\x45_VoiceRecognition.proto\"C\n\x17\x64\x65\x63\x31\x30\x32\x32_vr_file_list_rq\x12\x13\n\x0b\x66ile_format\x18\x01 \x01(\r\x12\x13\n\x0bsuffix_type\x18\x02 \x01(\r\"\x99\x01\n\x17\x64\x65\x63\x31\x30\x32\x32_vr_file_list_ra\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.dec1022_vr_file_list_ra.file_info_t\x1aJ\n\x0b\x66ile_info_t\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12\x15\n\rfile_duration\x18\x02 \x01(\r\x12\x11\n\tfile_date\x18\x03 \x01(\r\"p\n\x1f\x64\x65\x63\x31\x30\x32\x36_vr_effect_play_start_rq\x12\x11\n\tfile_type\x18\x01 \x01(\t\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12\x13\n\x0b\x66ile_format\x18\x03 \x01(\r\x12\x12\n\nsession_id\x18\x04 \x01(\r\"!\n\x1f\x64\x65\x63\x31\x30\x32\x36_vr_effect_play_start_ra\"]\n\x1f\x64\x65\x63\x31\x30\x32\x37_vr_record_play_start_rq\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12\x13\n\x0b\x66ile_format\x18\x02 \x01(\r\x12\x12\n\nsession_id\x18\x03 \x01(\r\"!\n\x1f\x64\x65\x63\x31\x30\x32\x37_vr_record_play_start_ra\"\x1e\n\x1c\x64\x65\x63\x31\x30\x32\x38_vr_file_play_stop_rq\"\x1e\n\x1c\x64\x65\x63\x31\x30\x32\x38_vr_file_play_stop_ra\"L\n\x16\x64\x65\x63\x31\x30\x33\x30_vr_tts_play_rq\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x12\n\nsession_id\x18\x03 \x01(\r\"\x18\n\x16\x64\x65\x63\x31\x30\x33\x30_vr_tts_play_ra\")\n\x18\x64\x65\x63\x31\x30\x33\x35_vr_set_volume_rq\x12\r\n\x05value\x18\x01 \x01(\r\"\x1a\n\x18\x64\x65\x63\x31\x30\x33\x35_vr_set_volume_ra\"\x1a\n\x18\x64\x65\x63\x31\x30\x33\x36_vr_get_volume_rq\")\n\x18\x64\x65\x63\x31\x30\x33\x36_vr_get_volume_ra\x12\r\n\x05value\x18\x01 \x01(\r\"B\n\x16\x64\x65\x63\x31\x30\x33\x39_vr_file_num_rq\x12\x13\n\x0b\x66ile_format\x18\x01 \x01(\r\x12\x13\n\x0bsuffix_type\x18\x02 \x01(\r\"*\n\x16\x64\x65\x63\x31\x30\x33\x39_vr_file_num_ra\x12\x10\n\x08\x66ile_num\x18\x01 \x01(\r\"\x18\n\x16\x64\x65\x63\x31\x30\x34\x31_vr_tts_stop_rq\"\x18\n\x16\x64\x65\x63\x31\x30\x34\x31_vr_tts_stop_ra\"\x18\n\x16\x64\x65\x63\x31\x30\x34\x32_vr_dir_init_rq\"\x18\n\x16\x64\x65\x63\x31\x30\x34\x32_vr_dir_init_ra\"\x17\n\x15\x64\x65\x63\x31\x30\x34\x33_vr_dir_get_rq\"$\n\x15\x64\x65\x63\x31\x30\x34\x33_vr_dir_get_ra\x12\x0b\n\x03\x64ir\x18\x01 \x01(\r\"+\n\x17\x64\x65\x63\x31\x30\x33\x32_vr_asr_start_rq\x12\x10\n\x08language\x18\x01 \x01(\t\"\x19\n\x17\x64\x65\x63\x31\x30\x33\x32_vr_asr_start_ra\"\x18\n\x16\x64\x65\x63\x31\x30\x33\x33_vr_asr_stop_rq\"\x18\n\x16\x64\x65\x63\x31\x30\x33\x33_vr_asr_stop_ra\"\x1c\n\x1a\x64\x65\x63\x31\x30\x34\x34_vr_asr_get_text_rq\"*\n\x1a\x64\x65\x63\x31\x30\x34\x34_vr_asr_get_text_ra\x12\x0c\n\x04text\x18\x01 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dE_VoiceRecognition_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DEC1022_VR_FILE_LIST_RQ._serialized_start=29
  _DEC1022_VR_FILE_LIST_RQ._serialized_end=96
  _DEC1022_VR_FILE_LIST_RA._serialized_start=99
  _DEC1022_VR_FILE_LIST_RA._serialized_end=252
  _DEC1022_VR_FILE_LIST_RA_FILE_INFO_T._serialized_start=178
  _DEC1022_VR_FILE_LIST_RA_FILE_INFO_T._serialized_end=252
  _DEC1026_VR_EFFECT_PLAY_START_RQ._serialized_start=254
  _DEC1026_VR_EFFECT_PLAY_START_RQ._serialized_end=366
  _DEC1026_VR_EFFECT_PLAY_START_RA._serialized_start=368
  _DEC1026_VR_EFFECT_PLAY_START_RA._serialized_end=401
  _DEC1027_VR_RECORD_PLAY_START_RQ._serialized_start=403
  _DEC1027_VR_RECORD_PLAY_START_RQ._serialized_end=496
  _DEC1027_VR_RECORD_PLAY_START_RA._serialized_start=498
  _DEC1027_VR_RECORD_PLAY_START_RA._serialized_end=531
  _DEC1028_VR_FILE_PLAY_STOP_RQ._serialized_start=533
  _DEC1028_VR_FILE_PLAY_STOP_RQ._serialized_end=563
  _DEC1028_VR_FILE_PLAY_STOP_RA._serialized_start=565
  _DEC1028_VR_FILE_PLAY_STOP_RA._serialized_end=595
  _DEC1030_VR_TTS_PLAY_RQ._serialized_start=597
  _DEC1030_VR_TTS_PLAY_RQ._serialized_end=673
  _DEC1030_VR_TTS_PLAY_RA._serialized_start=675
  _DEC1030_VR_TTS_PLAY_RA._serialized_end=699
  _DEC1035_VR_SET_VOLUME_RQ._serialized_start=701
  _DEC1035_VR_SET_VOLUME_RQ._serialized_end=742
  _DEC1035_VR_SET_VOLUME_RA._serialized_start=744
  _DEC1035_VR_SET_VOLUME_RA._serialized_end=770
  _DEC1036_VR_GET_VOLUME_RQ._serialized_start=772
  _DEC1036_VR_GET_VOLUME_RQ._serialized_end=798
  _DEC1036_VR_GET_VOLUME_RA._serialized_start=800
  _DEC1036_VR_GET_VOLUME_RA._serialized_end=841
  _DEC1039_VR_FILE_NUM_RQ._serialized_start=843
  _DEC1039_VR_FILE_NUM_RQ._serialized_end=909
  _DEC1039_VR_FILE_NUM_RA._serialized_start=911
  _DEC1039_VR_FILE_NUM_RA._serialized_end=953
  _DEC1041_VR_TTS_STOP_RQ._serialized_start=955
  _DEC1041_VR_TTS_STOP_RQ._serialized_end=979
  _DEC1041_VR_TTS_STOP_RA._serialized_start=981
  _DEC1041_VR_TTS_STOP_RA._serialized_end=1005
  _DEC1042_VR_DIR_INIT_RQ._serialized_start=1007
  _DEC1042_VR_DIR_INIT_RQ._serialized_end=1031
  _DEC1042_VR_DIR_INIT_RA._serialized_start=1033
  _DEC1042_VR_DIR_INIT_RA._serialized_end=1057
  _DEC1043_VR_DIR_GET_RQ._serialized_start=1059
  _DEC1043_VR_DIR_GET_RQ._serialized_end=1082
  _DEC1043_VR_DIR_GET_RA._serialized_start=1084
  _DEC1043_VR_DIR_GET_RA._serialized_end=1120
  _DEC1032_VR_ASR_START_RQ._serialized_start=1122
  _DEC1032_VR_ASR_START_RQ._serialized_end=1165
  _DEC1032_VR_ASR_START_RA._serialized_start=1167
  _DEC1032_VR_ASR_START_RA._serialized_end=1192
  _DEC1033_VR_ASR_STOP_RQ._serialized_start=1194
  _DEC1033_VR_ASR_STOP_RQ._serialized_end=1218
  _DEC1033_VR_ASR_STOP_RA._serialized_start=1220
  _DEC1033_VR_ASR_STOP_RA._serialized_end=1244
  _DEC1044_VR_ASR_GET_TEXT_RQ._serialized_start=1246
  _DEC1044_VR_ASR_GET_TEXT_RQ._serialized_end=1274
  _DEC1044_VR_ASR_GET_TEXT_RA._serialized_start=1276
  _DEC1044_VR_ASR_GET_TEXT_RA._serialized_end=1318
# @@protoc_insertion_point(module_scope)
