# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: d20_VisionModule.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x64\x32\x30_VisionModule.proto\"%\n#d20c1003_visionmodule_mid_offset_rq\"5\n#d20c1003_visionmodule_mid_offset_ra\x12\x0e\n\x06offset\x18\x01 \x01(\x02\"2\n!d20c1005_visionmodule_identify_rq\x12\r\n\x05model\x18\x01 \x01(\x11\"\xe7\x01\n!d20c1005_visionmodule_identify_ra\x12\r\n\x05model\x18\x01 \x01(\x11\x12>\n\x04info\x18\x02 \x03(\x0b\x32\x30.d20c1005_visionmodule_identify_ra.identify_info\x1as\n\ridentify_info\x12\x0b\n\x03tid\x18\x01 \x01(\x11\x12\r\n\x05tname\x18\x02 \x01(\t\x12\x0b\n\x03\x65id\x18\x03 \x01(\x11\x12\r\n\x05\x65name\x18\x04 \x01(\t\x12\t\n\x01x\x18\x05 \x01(\r\x12\t\n\x01y\x18\x06 \x01(\r\x12\t\n\x01w\x18\x07 \x01(\r\x12\t\n\x01h\x18\x08 \x01(\r\"6\n%d20c1008_visionmodule_model_switch_rq\x12\r\n\x05model\x18\x01 \x01(\x11\"7\n%d20c1008_visionmodule_model_switch_ra\x12\x0e\n\x06result\x18\x01 \x01(\x11\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'd20_VisionModule_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _D20C1003_VISIONMODULE_MID_OFFSET_RQ._serialized_start=26
  _D20C1003_VISIONMODULE_MID_OFFSET_RQ._serialized_end=63
  _D20C1003_VISIONMODULE_MID_OFFSET_RA._serialized_start=65
  _D20C1003_VISIONMODULE_MID_OFFSET_RA._serialized_end=118
  _D20C1005_VISIONMODULE_IDENTIFY_RQ._serialized_start=120
  _D20C1005_VISIONMODULE_IDENTIFY_RQ._serialized_end=170
  _D20C1005_VISIONMODULE_IDENTIFY_RA._serialized_start=173
  _D20C1005_VISIONMODULE_IDENTIFY_RA._serialized_end=404
  _D20C1005_VISIONMODULE_IDENTIFY_RA_IDENTIFY_INFO._serialized_start=289
  _D20C1005_VISIONMODULE_IDENTIFY_RA_IDENTIFY_INFO._serialized_end=404
  _D20C1008_VISIONMODULE_MODEL_SWITCH_RQ._serialized_start=406
  _D20C1008_VISIONMODULE_MODEL_SWITCH_RQ._serialized_end=460
  _D20C1008_VISIONMODULE_MODEL_SWITCH_RA._serialized_start=462
  _D20C1008_VISIONMODULE_MODEL_SWITCH_RA._serialized_end=517
# @@protoc_insertion_point(module_scope)
