# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: d5_Infrared.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x64\x35_Infrared.proto\"\x17\n\x15\x64\x35\x63\x31\x30\x30\x31_ir_dis_get_rq\")\n\x15\x64\x35\x63\x31\x30\x30\x31_ir_dis_get_ra\x12\x10\n\x08\x64istance\x18\x01 \x01(\rb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'd5_Infrared_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _D5C1001_IR_DIS_GET_RQ._serialized_start=21
  _D5C1001_IR_DIS_GET_RQ._serialized_end=44
  _D5C1001_IR_DIS_GET_RA._serialized_start=46
  _D5C1001_IR_DIS_GET_RA._serialized_end=87
# @@protoc_insertion_point(module_scope)
