# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: d8_Led.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x64\x38_Led.proto\"R\n\x1a\x64\x38\x63\x31\x30\x30\x30_led_fix_exp_set_rq\x12\x18\n\x10\x65xpressions_type\x18\x01 \x01(\r\x12\x0c\n\x04time\x18\x02 \x01(\r\x12\x0c\n\x04rgbc\x18\x03 \x01(\r\"\x1c\n\x1a\x64\x38\x63\x31\x30\x30\x30_led_fix_exp_set_ra\"\x91\x01\n\x16\x64\x38\x63\x31\x30\x30\x31_led_exp_set_rq\x12\x0c\n\x04time\x18\x01 \x01(\r\x12:\n\ncolor_lump\x18\x02 \x03(\x0b\x32&.d8c1001_led_exp_set_rq.dev_color_lump\x1a-\n\x0e\x64\x65v_color_lump\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0c\n\x04rgbc\x18\x02 \x01(\r\"\x18\n\x16\x64\x38\x63\x31\x30\x30\x31_led_exp_set_rab\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'd8_Led_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _D8C1000_LED_FIX_EXP_SET_RQ._serialized_start=16
  _D8C1000_LED_FIX_EXP_SET_RQ._serialized_end=98
  _D8C1000_LED_FIX_EXP_SET_RA._serialized_start=100
  _D8C1000_LED_FIX_EXP_SET_RA._serialized_end=128
  _D8C1001_LED_EXP_SET_RQ._serialized_start=131
  _D8C1001_LED_EXP_SET_RQ._serialized_end=276
  _D8C1001_LED_EXP_SET_RQ_DEV_COLOR_LUMP._serialized_start=231
  _D8C1001_LED_EXP_SET_RQ_DEV_COLOR_LUMP._serialized_end=276
  _D8C1001_LED_EXP_SET_RA._serialized_start=278
  _D8C1001_LED_EXP_SET_RA._serialized_end=302
# @@protoc_insertion_point(module_scope)
