# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: header.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cheader.proto\"\xd2\x01\n\x06Header\x12\x0b\n\x03\x64\x65v\x18\x01 \x01(\r\x12\x0b\n\x03\x63md\x18\x02 \x01(\r\x12\n\n\x02id\x18\x03 \x01(\r\x12\x0f\n\x07\x64\x61taLen\x18\x04 \x01(\r\x12\x1a\n\x04\x61ttr\x18\x05 \x01(\x0e\x32\x0c.Header.Attr\x12\x0b\n\x03\x61\x63k\x18\x06 \x01(\x11\x12\x0b\n\x03seq\x18\x07 \x01(\r\"[\n\x04\x41ttr\x12\x0b\n\x07RESERVE\x10\x00\x12\x0b\n\x07REQUEST\x10\x01\x12\n\n\x06REQACK\x10\x02\x12\x0b\n\x07PUBLISH\x10\x03\x12\n\n\x06PUBACK\x10\x04\x12\n\n\x06NOTIFY\x10\x05\x12\x08\n\x04PUSH\x10\x06\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'header_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _HEADER._serialized_start=17
  _HEADER._serialized_end=227
  _HEADER_ATTR._serialized_start=136
  _HEADER_ATTR._serialized_end=227
# @@protoc_insertion_point(module_scope)
