"""定义外设类型 """
INFRARED = 0x5
TOUCH = 0xb
ULTRASOUND = 0x9
COLOR = 0xd
HUMITURE = 0x6
ENV_LIGHT = 0x11
SOUND = 0x7
SERVO = 0x3
MOTOR = 0x4
LED = 0x8
LIGHT_BOX = 0x1a
BATTERY = 0xf
AUDIO = 0xe
LCD = 0x1b
VISION = 0x20
INTELLIGENT_DEVICE = 0x2
