# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dD_Color.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x64\x44_Color.proto\"\x18\n\x16\x64\x64\x63\x31\x30\x30\x30_clr_rgb_get_rq\"&\n\x16\x64\x64\x63\x31\x30\x30\x30_clr_rgb_get_ra\x12\x0c\n\x04rgbc\x18\x01 \x01(\rb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dD_Color_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DDC1000_CLR_RGB_GET_RQ._serialized_start=18
  _DDC1000_CLR_RGB_GET_RQ._serialized_end=42
  _DDC1000_CLR_RGB_GET_RA._serialized_start=44
  _DDC1000_CLR_RGB_GET_RA._serialized_end=82
# @@protoc_insertion_point(module_scope)
