# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dF_Battery.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x64\x46_Battery.proto\"\x18\n\x16\x64\x66\x63\x31\x30\x30\x30_bat_pwr_pct_rq\"-\n\x16\x64\x66\x63\x31\x30\x30\x30_bat_pwr_pct_ra\x12\x13\n\x0bpwr_percent\x18\x01 \x01(\r\"\x1b\n\x19\x64\x66\x63\x31\x30\x30\x31_bat_status_get_rq\"G\n\x19\x64\x66\x63\x31\x30\x30\x31_bat_status_get_ra\x12\x12\n\nbat_status\x18\x01 \x01(\r\x12\x16\n\x0e\x61\x64\x61pter_status\x18\x02 \x01(\rb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dF_Battery_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DFC1000_BAT_PWR_PCT_RQ._serialized_start=20
  _DFC1000_BAT_PWR_PCT_RQ._serialized_end=44
  _DFC1000_BAT_PWR_PCT_RA._serialized_start=46
  _DFC1000_BAT_PWR_PCT_RA._serialized_end=91
  _DFC1001_BAT_STATUS_GET_RQ._serialized_start=93
  _DFC1001_BAT_STATUS_GET_RQ._serialized_end=120
  _DFC1001_BAT_STATUS_GET_RA._serialized_start=122
  _DFC1001_BAT_STATUS_GET_RA._serialized_end=193
# @@protoc_insertion_point(module_scope)
