# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: d4_Motor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x64\x34_Motor.proto\"7\n\x18\x64\x34\x63\x31\x30\x30\x30_mtr_speed_set_rq\x12\r\n\x05speed\x18\x01 \x01(\x11\x12\x0c\n\x04time\x18\x02 \x01(\r\"\x1a\n\x18\x64\x34\x63\x31\x30\x30\x30_mtr_speed_set_ra\"\x15\n\x13\x64\x34\x63\x31\x30\x30\x31_mtr_stop_rq\"\x15\n\x13\x64\x34\x63\x31\x30\x30\x31_mtr_stop_ra\"%\n\x16\x64\x34\x63\x31\x30\x30\x34_mtr_pwm_set_rq\x12\x0b\n\x03pwm\x18\x01 \x01(\x11\"\x18\n\x16\x64\x34\x63\x31\x30\x30\x34_mtr_pwm_set_rab\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'd4_Motor_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _D4C1000_MTR_SPEED_SET_RQ._serialized_start=18
  _D4C1000_MTR_SPEED_SET_RQ._serialized_end=73
  _D4C1000_MTR_SPEED_SET_RA._serialized_start=75
  _D4C1000_MTR_SPEED_SET_RA._serialized_end=101
  _D4C1001_MTR_STOP_RQ._serialized_start=103
  _D4C1001_MTR_STOP_RQ._serialized_end=124
  _D4C1001_MTR_STOP_RA._serialized_start=126
  _D4C1001_MTR_STOP_RA._serialized_end=147
  _D4C1004_MTR_PWM_SET_RQ._serialized_start=149
  _D4C1004_MTR_PWM_SET_RQ._serialized_end=186
  _D4C1004_MTR_PWM_SET_RA._serialized_start=188
  _D4C1004_MTR_PWM_SET_RA._serialized_end=212
# @@protoc_insertion_point(module_scope)
