# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: d3_Servo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x64\x33_Servo.proto\"j\n\x18\x64\x33\x63\x31\x30\x30\x30_srv_angle_set_rq\x12\x11\n\ttar_angle\x18\x01 \x01(\x11\x12\x15\n\rrotation_time\x18\x02 \x01(\r\x12\x16\n\x0eshielding_time\x18\x03 \x01(\r\x12\x0c\n\x04mode\x18\x04 \x01(\r\"\x1a\n\x18\x64\x33\x63\x31\x30\x30\x30_srv_angle_set_ra\"\'\n\x18\x64\x33\x63\x31\x30\x30\x31_srv_angle_get_rq\x12\x0b\n\x03pwr\x18\x01 \x01(\x08\"@\n\x18\x64\x33\x63\x31\x30\x30\x31_srv_angle_get_ra\x12\x11\n\tcur_angle\x18\x01 \x01(\x11\x12\x11\n\ttar_angle\x18\x02 \x01(\x11\"%\n\x16\x64\x33\x63\x31\x30\x30\x32_srv_pwm_set_rq\x12\x0b\n\x03pwm\x18\x01 \x01(\x11\"\x18\n\x16\x64\x33\x63\x31\x30\x30\x32_srv_pwm_set_ra\"#\n\x13\x64\x33\x63\x31\x30\x30\x34_srv_stop_rq\x12\x0c\n\x04mode\x18\x01 \x01(\r\"\x15\n\x13\x64\x33\x63\x31\x30\x30\x34_srv_stop_rab\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'd3_Servo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _D3C1000_SRV_ANGLE_SET_RQ._serialized_start=18
  _D3C1000_SRV_ANGLE_SET_RQ._serialized_end=124
  _D3C1000_SRV_ANGLE_SET_RA._serialized_start=126
  _D3C1000_SRV_ANGLE_SET_RA._serialized_end=152
  _D3C1001_SRV_ANGLE_GET_RQ._serialized_start=154
  _D3C1001_SRV_ANGLE_GET_RQ._serialized_end=193
  _D3C1001_SRV_ANGLE_GET_RA._serialized_start=195
  _D3C1001_SRV_ANGLE_GET_RA._serialized_end=259
  _D3C1002_SRV_PWM_SET_RQ._serialized_start=261
  _D3C1002_SRV_PWM_SET_RQ._serialized_end=298
  _D3C1002_SRV_PWM_SET_RA._serialized_start=300
  _D3C1002_SRV_PWM_SET_RA._serialized_end=324
  _D3C1004_SRV_STOP_RQ._serialized_start=326
  _D3C1004_SRV_STOP_RQ._serialized_end=361
  _D3C1004_SRV_STOP_RA._serialized_start=363
  _D3C1004_SRV_STOP_RA._serialized_end=384
# @@protoc_insertion_point(module_scope)
