INFRARED_DISTANCE = 0
ULTRASONIC_DISTANCE = 1
SOUND_STRONG = 2
BRIGHTNESS = 3
HUMIDITY = 4
TEMPERATURE_F = 6
TEMPERATURE_C = 5
COLOR_RED = 7
COLOR_GREEN = 8
COLOR_BLUE = 9
SERVO_ANGLE = 10
BATTERY_LEVEL = 11
BATTERY_STATUS = 12
CHARGE_STATUS = 13
TOUCH_STATUS = 14
