# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: d1A_LedBelt.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x64\x31\x41_LedBelt.proto\"\x9d\x01\n\x1c\x64\x31\x61\x63\x31\x30\x30\x30_led_belt_exp_set_rq\x12\x0c\n\x04port\x18\x01 \x01(\r\x12@\n\ncolor_lump\x18\x02 \x03(\x0b\x32,.d1ac1000_led_belt_exp_set_rq.dev_color_lump\x1a-\n\x0e\x64\x65v_color_lump\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0c\n\x04rgbc\x18\x02 \x01(\r\"\x1e\n\x1c\x64\x31\x61\x63\x31\x30\x30\x30_led_belt_exp_set_ra\"#\n!d1ac1001_led_belt_leds_num_get_rq\"\x93\x01\n!d1ac1001_led_belt_leds_num_get_ra\x12\x41\n\x08num_lump\x18\x01 \x03(\x0b\x32/.d1ac1001_led_belt_leds_num_get_ra.dev_num_lump\x1a+\n\x0c\x64\x65v_num_lump\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\r\n\x05total\x18\x02 \x01(\r\"f\n d1ac1002_led_belt_fix_exp_set_rq\x12\x18\n\x10\x65xpressions_type\x18\x01 \x01(\r\x12\x0c\n\x04time\x18\x02 \x01(\r\x12\x0c\n\x04rgbc\x18\x03 \x01(\r\x12\x0c\n\x04port\x18\x04 \x01(\r\"\"\n d1ac1002_led_belt_fix_exp_set_ra\"\x8e\x01\n#d1ac1003_led_belt_brightness_set_rq\x12=\n\nbrightness\x18\x01 \x03(\x0b\x32).d1ac1003_led_belt_brightness_set_rq.info\x1a(\n\x04info\x12\x12\n\nbrightness\x18\x01 \x01(\r\x12\x0c\n\x04port\x18\x02 \x01(\r\"%\n#d1ac1003_led_belt_brightness_set_ra\",\n\x1c\x64\x31\x61\x63\x31\x30\x30\x34_led_belt_off_set_rq\x12\x0c\n\x04port\x18\x01 \x03(\r\"\x1e\n\x1c\x64\x31\x61\x63\x31\x30\x30\x34_led_belt_off_set_ra\"\x85\x01\n\x1d\x64\x31\x61\x63\x31\x30\x30\x35_led_belt_move_set_rq\x12\x31\n\x04move\x18\x01 \x03(\x0b\x32#.d1ac1005_led_belt_move_set_rq.info\x1a\x31\n\x04info\x12\r\n\x05pixel\x18\x01 \x01(\r\x12\x0c\n\x04time\x18\x02 \x01(\r\x12\x0c\n\x04port\x18\x03 \x01(\r\"\x1f\n\x1d\x64\x31\x61\x63\x31\x30\x30\x35_led_belt_move_set_ra\"\xc3\x01\n/d1ac1006_led_belt_expressions_continuous_set_rq\x12\x44\n\x05pixel\x18\x01 \x03(\x0b\x32\x35.d1ac1006_led_belt_expressions_continuous_set_rq.info\x1aJ\n\x04info\x12\x13\n\x0bstart_pixel\x18\x01 \x01(\r\x12\x11\n\tend_pixel\x18\x02 \x01(\r\x12\x0c\n\x04rgbc\x18\x03 \x01(\r\x12\x0c\n\x04port\x18\x04 \x01(\r\"1\n/d1ac1006_led_belt_expressions_continuous_set_ra\"\xdf\x01\n6d1ac1007_led_belt_expressions_continuous_breath_set_rq\x12K\n\x05pixel\x18\x01 \x03(\x0b\x32<.d1ac1007_led_belt_expressions_continuous_breath_set_rq.info\x1aX\n\x04info\x12\x13\n\x0bstart_pixel\x18\x01 \x01(\r\x12\x11\n\tend_pixel\x18\x02 \x01(\r\x12\x0c\n\x04rgbc\x18\x03 \x01(\r\x12\x0c\n\x04time\x18\x04 \x01(\r\x12\x0c\n\x04port\x18\x05 \x01(\r\"8\n6d1ac1007_led_belt_expressions_continuous_breath_set_rab\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'd1A_LedBelt_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _D1AC1000_LED_BELT_EXP_SET_RQ._serialized_start=22
  _D1AC1000_LED_BELT_EXP_SET_RQ._serialized_end=179
  _D1AC1000_LED_BELT_EXP_SET_RQ_DEV_COLOR_LUMP._serialized_start=134
  _D1AC1000_LED_BELT_EXP_SET_RQ_DEV_COLOR_LUMP._serialized_end=179
  _D1AC1000_LED_BELT_EXP_SET_RA._serialized_start=181
  _D1AC1000_LED_BELT_EXP_SET_RA._serialized_end=211
  _D1AC1001_LED_BELT_LEDS_NUM_GET_RQ._serialized_start=213
  _D1AC1001_LED_BELT_LEDS_NUM_GET_RQ._serialized_end=248
  _D1AC1001_LED_BELT_LEDS_NUM_GET_RA._serialized_start=251
  _D1AC1001_LED_BELT_LEDS_NUM_GET_RA._serialized_end=398
  _D1AC1001_LED_BELT_LEDS_NUM_GET_RA_DEV_NUM_LUMP._serialized_start=355
  _D1AC1001_LED_BELT_LEDS_NUM_GET_RA_DEV_NUM_LUMP._serialized_end=398
  _D1AC1002_LED_BELT_FIX_EXP_SET_RQ._serialized_start=400
  _D1AC1002_LED_BELT_FIX_EXP_SET_RQ._serialized_end=502
  _D1AC1002_LED_BELT_FIX_EXP_SET_RA._serialized_start=504
  _D1AC1002_LED_BELT_FIX_EXP_SET_RA._serialized_end=538
  _D1AC1003_LED_BELT_BRIGHTNESS_SET_RQ._serialized_start=541
  _D1AC1003_LED_BELT_BRIGHTNESS_SET_RQ._serialized_end=683
  _D1AC1003_LED_BELT_BRIGHTNESS_SET_RQ_INFO._serialized_start=643
  _D1AC1003_LED_BELT_BRIGHTNESS_SET_RQ_INFO._serialized_end=683
  _D1AC1003_LED_BELT_BRIGHTNESS_SET_RA._serialized_start=685
  _D1AC1003_LED_BELT_BRIGHTNESS_SET_RA._serialized_end=722
  _D1AC1004_LED_BELT_OFF_SET_RQ._serialized_start=724
  _D1AC1004_LED_BELT_OFF_SET_RQ._serialized_end=768
  _D1AC1004_LED_BELT_OFF_SET_RA._serialized_start=770
  _D1AC1004_LED_BELT_OFF_SET_RA._serialized_end=800
  _D1AC1005_LED_BELT_MOVE_SET_RQ._serialized_start=803
  _D1AC1005_LED_BELT_MOVE_SET_RQ._serialized_end=936
  _D1AC1005_LED_BELT_MOVE_SET_RQ_INFO._serialized_start=887
  _D1AC1005_LED_BELT_MOVE_SET_RQ_INFO._serialized_end=936
  _D1AC1005_LED_BELT_MOVE_SET_RA._serialized_start=938
  _D1AC1005_LED_BELT_MOVE_SET_RA._serialized_end=969
  _D1AC1006_LED_BELT_EXPRESSIONS_CONTINUOUS_SET_RQ._serialized_start=972
  _D1AC1006_LED_BELT_EXPRESSIONS_CONTINUOUS_SET_RQ._serialized_end=1167
  _D1AC1006_LED_BELT_EXPRESSIONS_CONTINUOUS_SET_RQ_INFO._serialized_start=1093
  _D1AC1006_LED_BELT_EXPRESSIONS_CONTINUOUS_SET_RQ_INFO._serialized_end=1167
  _D1AC1006_LED_BELT_EXPRESSIONS_CONTINUOUS_SET_RA._serialized_start=1169
  _D1AC1006_LED_BELT_EXPRESSIONS_CONTINUOUS_SET_RA._serialized_end=1218
  _D1AC1007_LED_BELT_EXPRESSIONS_CONTINUOUS_BREATH_SET_RQ._serialized_start=1221
  _D1AC1007_LED_BELT_EXPRESSIONS_CONTINUOUS_BREATH_SET_RQ._serialized_end=1444
  _D1AC1007_LED_BELT_EXPRESSIONS_CONTINUOUS_BREATH_SET_RQ_INFO._serialized_start=1356
  _D1AC1007_LED_BELT_EXPRESSIONS_CONTINUOUS_BREATH_SET_RQ_INFO._serialized_end=1444
  _D1AC1007_LED_BELT_EXPRESSIONS_CONTINUOUS_BREATH_SET_RA._serialized_start=1446
  _D1AC1007_LED_BELT_EXPRESSIONS_CONTINUOUS_BREATH_SET_RA._serialized_end=1502
# @@protoc_insertion_point(module_scope)
